svn commit: r1124697 [5/12] - in /ofbiz/trunk: framework/common/widget/ framework/images/webapp/images/jquery/ui/ framework/images/webapp/images/jquery/ui/css/ui-lightness/ framework/images/webapp/images/jquery/ui/development-bundle/ framework/images/w...

Previous Topic Next Topic
 
classic Classic list List threaded Threaded
1 message Options
Reply | Threaded
Open this post in threaded view
|

svn commit: r1124697 [5/12] - in /ofbiz/trunk: framework/common/widget/ framework/images/webapp/images/jquery/ui/ framework/images/webapp/images/jquery/ui/css/ui-lightness/ framework/images/webapp/images/jquery/ui/development-bundle/ framework/images/w...

sascharodekamp
Propchange: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery-ui-1.8.13.custom.js
------------------------------------------------------------------------------
    svn:mime-type = text/plain

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.blind.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Blind 1.8.11
+ * jQuery UI Effects Blind 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.bounce.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Bounce 1.8.11
+ * jQuery UI Effects Bounce 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.clip.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Clip 1.8.11
+ * jQuery UI Effects Clip 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Drop 1.8.11
+ * jQuery UI Effects Drop 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.explode.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Explode 1.8.11
+ * jQuery UI Effects Explode 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fade.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Fade 1.8.11
+ * jQuery UI Effects Fade 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.fold.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Fold 1.8.11
+ * jQuery UI Effects Fold 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.highlight.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Highlight 1.8.11
+ * jQuery UI Effects Highlight 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.pulsate.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Pulsate 1.8.11
+ * jQuery UI Effects Pulsate 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.scale.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Scale 1.8.11
+ * jQuery UI Effects Scale 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.shake.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Shake 1.8.11
+ * jQuery UI Effects Shake 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.slide.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Slide 1.8.11
+ * jQuery UI Effects Slide 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.transfer.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Transfer 1.8.11
+ * jQuery UI Effects Transfer 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Autocomplete 1.8.11
+ * jQuery UI Autocomplete 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -490,12 +490,12 @@ $.widget("ui.menu", {
  this.deactivate();
  if (this.hasScroll()) {
  var offset = item.offset().top - this.element.offset().top,
- scroll = this.element.attr("scrollTop"),
+ scroll = this.element.scrollTop(),
  elementHeight = this.element.height();
  if (offset < 0) {
- this.element.attr("scrollTop", scroll + offset);
+ this.element.scrollTop( scroll + offset);
  } else if (offset >= elementHeight) {
- this.element.attr("scrollTop", scroll + offset - elementHeight + item.height());
+ this.element.scrollTop( scroll + offset - elementHeight + item.height());
  }
  }
  this.active = item.eq(0)
@@ -601,7 +601,7 @@ $.widget("ui.menu", {
  },
 
  hasScroll: function() {
- return this.element.height() < this.element.attr("scrollHeight");
+ return this.element.height() < this.element[ $.fn.prop ? "prop" : "attr" ]("scrollHeight");
  },
 
  select: function( event ) {

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.button.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Button 1.8.11
+ * jQuery UI Button 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -102,6 +102,11 @@ $.widget( "ui.button", {
  })
  .bind( "blur.button", function() {
  $( this ).removeClass( focusClass );
+ })
+ .bind( "click.button", function( event ) {
+ if ( options.disabled ) {
+ event.stopImmediatePropagation();
+ }
  });
 
  if ( toggleButton ) {
@@ -182,21 +187,17 @@ $.widget( "ui.button", {
  },
 
  _determineButtonType: function() {
-
+
  if ( this.element.is(":checkbox") ) {
  this.type = "checkbox";
+ } else if ( this.element.is(":radio") ) {
+ this.type = "radio";
+ } else if ( this.element.is("input") ) {
+ this.type = "input";
  } else {
- if ( this.element.is(":radio") ) {
- this.type = "radio";
- } else {
- if ( this.element.is("input") ) {
- this.type = "input";
- } else {
- this.type = "button";
- }
- }
+ this.type = "button";
  }
-
+
  if ( this.type === "checkbox" || this.type === "radio" ) {
  // we don't search against the document in case the element
  // is disconnected from the DOM

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.core.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*!
- * jQuery UI 1.8.11
+ * jQuery UI 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -18,7 +18,7 @@ if ( $.ui.version ) {
 }
 
 $.extend( $.ui, {
- version: "1.8.11",
+ version: "1.8.13",
 
  keyCode: {
  ALT: 18,
@@ -174,6 +174,27 @@ $.each( [ "Width", "Height" ], function(
 });
 
 // selectors
+function focusable( element, isTabIndexNotNaN ) {
+ var nodeName = element.nodeName.toLowerCase();
+ if ( "area" === nodeName ) {
+ var map = element.parentNode,
+ mapName = map.name,
+ img;
+ if ( !element.href || !mapName || map.nodeName.toLowerCase() !== "map" ) {
+ return false;
+ }
+ img = $( "img[usemap=#" + mapName + "]" )[0];
+ return !!img && visible( img );
+ }
+ return ( /input|select|textarea|button|object/.test( nodeName )
+ ? !element.disabled
+ : "a" == nodeName
+ ? element.href || isTabIndexNotNaN
+ : isTabIndexNotNaN)
+ // the element and all of its ancestors must be visible
+ && visible( element );
+}
+
 function visible( element ) {
  return !$( element ).parents().andSelf().filter(function() {
  return $.curCSS( this, "visibility" ) === "hidden" ||
@@ -187,30 +208,13 @@ $.extend( $.expr[ ":" ], {
  },
 
  focusable: function( element ) {
- var nodeName = element.nodeName.toLowerCase(),
- tabIndex = $.attr( element, "tabindex" );
- if ( "area" === nodeName ) {
- var map = element.parentNode,
- mapName = map.name,
- img;
- if ( !element.href || !mapName || map.nodeName.toLowerCase() !== "map" ) {
- return false;
- }
- img = $( "img[usemap=#" + mapName + "]" )[0];
- return !!img && visible( img );
- }
- return ( /input|select|textarea|button|object/.test( nodeName )
- ? !element.disabled
- : "a" == nodeName
- ? element.href || !isNaN( tabIndex )
- : !isNaN( tabIndex ))
- // the element and all of its ancestors must be visible
- && visible( element );
+ return focusable( element, !isNaN( $.attr( element, "tabindex" ) ) );
  },
 
  tabbable: function( element ) {
- var tabIndex = $.attr( element, "tabindex" );
- return ( isNaN( tabIndex ) || tabIndex >= 0 ) && $( element ).is( ":focusable" );
+ var tabIndex = $.attr( element, "tabindex" ),
+ isTabIndexNaN = isNaN( tabIndex );
+ return ( isTabIndexNaN || tabIndex >= 0 ) && focusable( element, !isTabIndexNaN );
  }
 });
 

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.datepicker.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Datepicker 1.8.11
+ * jQuery UI Datepicker 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -12,10 +12,11 @@
  */
 (function( $, undefined ) {
 
-$.extend($.ui, { datepicker: { version: "1.8.11" } });
+$.extend($.ui, { datepicker: { version: "1.8.13" } });
 
 var PROP_NAME = 'datepicker';
 var dpuuid = new Date().getTime();
+var instActive;
 
 /* Date picker manager.
    Use the singleton instance of this class, $.datepicker, to interact with the date picker.
@@ -107,7 +108,7 @@ function Datepicker() {
  autoSize: false // True to size the input for the date format, false to leave as is
  };
  $.extend(this._defaults, this.regional['']);
- this.dpDiv = $('<div id="' + this._mainDivId + '" class="ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>');
+ this.dpDiv = bindHover($('<div id="' + this._mainDivId + '" class="ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>'));
 }
 
 $.extend(Datepicker.prototype, {
@@ -173,7 +174,7 @@ $.extend(Datepicker.prototype, {
  drawMonth: 0, drawYear: 0, // month being drawn
  inline: inline, // is datepicker inline or not
  dpDiv: (!inline ? this.dpDiv : // presentation div
- $('<div class="' + this._inlineClass + ' ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>'))};
+ bindHover($('<div class="' + this._inlineClass + ' ui-datepicker ui-widget ui-widget-content ui-helper-clearfix ui-corner-all"></div>')))};
  },
 
  /* Attach the date picker to an input field. */
@@ -363,6 +364,8 @@ $.extend(Datepicker.prototype, {
  else if (nodeName == 'div' || nodeName == 'span') {
  var inline = $target.children('.' + this._inlineClass);
  inline.children().removeClass('ui-state-disabled');
+ inline.find("select.ui-datepicker-month, select.ui-datepicker-year").
+ removeAttr("disabled");
  }
  this._disabledInputs = $.map(this._disabledInputs,
  function(value) { return (value == target ? null : value); }); // delete entry
@@ -386,6 +389,8 @@ $.extend(Datepicker.prototype, {
  else if (nodeName == 'div' || nodeName == 'span') {
  var inline = $target.children('.' + this._inlineClass);
  inline.children().addClass('ui-state-disabled');
+ inline.find("select.ui-datepicker-month, select.ui-datepicker-year").
+ attr("disabled", "disabled");
  }
  this._disabledInputs = $.map(this._disabledInputs,
  function(value) { return (value == target ? null : value); }); // delete entry
@@ -454,7 +459,8 @@ $.extend(Datepicker.prototype, {
  inst.settings.maxDate = this._formatDate(inst, maxDate);
  this._attachments($(target), inst);
  this._autoSize(inst);
- this._setDateDatepicker(target, date);
+ this._setDate(inst, date);
+ this._updateAlternate(inst);
  this._updateDatepicker(inst);
  }
  },
@@ -647,7 +653,6 @@ $.extend(Datepicker.prototype, {
  var showAnim = $.datepicker._get(inst, 'showAnim');
  var duration = $.datepicker._get(inst, 'duration');
  var postProcess = function() {
- $.datepicker._datepickerShowing = true;
  var cover = inst.dpDiv.find('iframe.ui-datepicker-cover'); // IE6- only
  if( !! cover.length ){
  var borders = $.datepicker._getBorders(inst.dpDiv);
@@ -656,6 +661,7 @@ $.extend(Datepicker.prototype, {
  }
  };
  inst.dpDiv.zIndex($(input).zIndex()+1);
+ $.datepicker._datepickerShowing = true;
  if ($.effects && $.effects[showAnim])
  inst.dpDiv.show(showAnim, $.datepicker._get(inst, 'showOptions'), duration, postProcess);
  else
@@ -672,36 +678,19 @@ $.extend(Datepicker.prototype, {
  _updateDatepicker: function(inst) {
  var self = this;
  var borders = $.datepicker._getBorders(inst.dpDiv);
+ instActive = inst; // for delegate hover events
  inst.dpDiv.empty().append(this._generateHTML(inst));
  var cover = inst.dpDiv.find('iframe.ui-datepicker-cover'); // IE6- only
  if( !!cover.length ){ //avoid call to outerXXXX() when not in IE6
  cover.css({left: -borders[0], top: -borders[1], width: inst.dpDiv.outerWidth(), height: inst.dpDiv.outerHeight()})
  }
- inst.dpDiv.find('button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a')
- .bind('mouseout', function(){
- $(this).removeClass('ui-state-hover');
- if(this.className.indexOf('ui-datepicker-prev') != -1) $(this).removeClass('ui-datepicker-prev-hover');
- if(this.className.indexOf('ui-datepicker-next') != -1) $(this).removeClass('ui-datepicker-next-hover');
- })
- .bind('mouseover', function(){
- if (!self._isDisabledDatepicker( inst.inline ? inst.dpDiv.parent()[0] : inst.input[0])) {
- $(this).parents('.ui-datepicker-calendar').find('a').removeClass('ui-state-hover');
- $(this).addClass('ui-state-hover');
- if(this.className.indexOf('ui-datepicker-prev') != -1) $(this).addClass('ui-datepicker-prev-hover');
- if(this.className.indexOf('ui-datepicker-next') != -1) $(this).addClass('ui-datepicker-next-hover');
- }
- })
- .end()
- .find('.' + this._dayOverClass + ' a')
- .trigger('mouseover')
- .end();
+ inst.dpDiv.find('.' + this._dayOverClass + ' a').mouseover();
  var numMonths = this._getNumberOfMonths(inst);
  var cols = numMonths[1];
  var width = 17;
+ inst.dpDiv.removeClass('ui-datepicker-multi-2 ui-datepicker-multi-3 ui-datepicker-multi-4').width('');
  if (cols > 1)
  inst.dpDiv.addClass('ui-datepicker-multi-' + cols).css('width', (width * cols) + 'em');
- else
- inst.dpDiv.removeClass('ui-datepicker-multi-2 ui-datepicker-multi-3 ui-datepicker-multi-4').width('');
  inst.dpDiv[(numMonths[0] != 1 || numMonths[1] != 1 ? 'add' : 'remove') +
  'Class']('ui-datepicker-multi');
  inst.dpDiv[(this._get(inst, 'isRTL') ? 'add' : 'remove') +
@@ -716,7 +705,7 @@ $.extend(Datepicker.prototype, {
  var origyearshtml = inst.yearshtml;
  setTimeout(function(){
  //assure that inst.yearshtml didn't change.
- if( origyearshtml === inst.yearshtml ){
+ if( origyearshtml === inst.yearshtml && inst.yearshtml ){
  inst.dpDiv.find('select.ui-datepicker-year:first').replaceWith(inst.yearshtml);
  }
  origyearshtml = inst.yearshtml = null;
@@ -1007,14 +996,24 @@ $.extend(Datepicker.prototype, {
  };
  // Extract a name from the string value and convert to an index
  var getName = function(match, shortNames, longNames) {
- var names = (lookAhead(match) ? longNames : shortNames);
- for (var i = 0; i < names.length; i++) {
- if (value.substr(iValue, names[i].length).toLowerCase() == names[i].toLowerCase()) {
- iValue += names[i].length;
- return i + 1;
+ var names = $.map(lookAhead(match) ? longNames : shortNames, function (v, k) {
+ return [ [k, v] ];
+ }).sort(function (a, b) {
+ return -(a[1].length - b[1].length);
+ });
+ var index = -1;
+ $.each(names, function (i, pair) {
+ var name = pair[1];
+ if (value.substr(iValue, name.length).toLowerCase() == name.toLowerCase()) {
+ index = pair[0];
+ iValue += name.length;
+ return false;
  }
- }
- throw 'Unknown name at position ' + iValue;
+ });
+ if (index != -1)
+ return index + 1;
+ else
+ throw 'Unknown name at position ' + iValue;
  };
  // Confirm that a literal character matches the string value
  var checkLiteral = function() {
@@ -1089,7 +1088,7 @@ $.extend(Datepicker.prototype, {
  }
  var date = this._daylightSavingAdjust(new Date(year, month - 1, day));
  if (date.getFullYear() != year || date.getMonth() + 1 != month || date.getDate() != day)
- throw 'Invalid date'; // E.g. 31/02/*
+ throw 'Invalid date'; // E.g. 31/02/00
  return date;
  },
 
@@ -1575,40 +1574,37 @@ $.extend(Datepicker.prototype, {
  if (!showMonthAfterYear)
  html += monthHtml + (secondary || !(changeMonth && changeYear) ? '&#xa0;' : '');
  // year selection
- inst.yearshtml = '';
- if (secondary || !changeYear)
- html += '<span class="ui-datepicker-year">' + drawYear + '</span>';
- else {
- // determine range of years to display
- var years = this._get(inst, 'yearRange').split(':');
- var thisYear = new Date().getFullYear();
- var determineYear = function(value) {
- var year = (value.match(/c[+-].*/) ? drawYear + parseInt(value.substring(1), 10) :
- (value.match(/[+-].*/) ? thisYear + parseInt(value, 10) :
- parseInt(value, 10)));
- return (isNaN(year) ? thisYear : year);
- };
- var year = determineYear(years[0]);
- var endYear = Math.max(year, determineYear(years[1] || ''));
- year = (minDate ? Math.max(year, minDate.getFullYear()) : year);
- endYear = (maxDate ? Math.min(endYear, maxDate.getFullYear()) : endYear);
- inst.yearshtml += '<select class="ui-datepicker-year" ' +
- 'onchange="DP_jQuery_' + dpuuid + '.datepicker._selectMonthYear(\'#' + inst.id + '\', this, \'Y\');" ' +
- 'onclick="DP_jQuery_' + dpuuid + '.datepicker._clickMonthYear(\'#' + inst.id + '\');"' +
- '>';
- for (; year <= endYear; year++) {
- inst.yearshtml += '<option value="' + year + '"' +
- (year == drawYear ? ' selected="selected"' : '') +
- '>' + year + '</option>';
- }
- inst.yearshtml += '</select>';
- //when showing there is no need for later update
- if( ! $.browser.mozilla ){
+ if ( !inst.yearshtml ) {
+ inst.yearshtml = '';
+ if (secondary || !changeYear)
+ html += '<span class="ui-datepicker-year">' + drawYear + '</span>';
+ else {
+ // determine range of years to display
+ var years = this._get(inst, 'yearRange').split(':');
+ var thisYear = new Date().getFullYear();
+ var determineYear = function(value) {
+ var year = (value.match(/c[+-].*/) ? drawYear + parseInt(value.substring(1), 10) :
+ (value.match(/[+-].*/) ? thisYear + parseInt(value, 10) :
+ parseInt(value, 10)));
+ return (isNaN(year) ? thisYear : year);
+ };
+ var year = determineYear(years[0]);
+ var endYear = Math.max(year, determineYear(years[1] || ''));
+ year = (minDate ? Math.max(year, minDate.getFullYear()) : year);
+ endYear = (maxDate ? Math.min(endYear, maxDate.getFullYear()) : endYear);
+ inst.yearshtml += '<select class="ui-datepicker-year" ' +
+ 'onchange="DP_jQuery_' + dpuuid + '.datepicker._selectMonthYear(\'#' + inst.id + '\', this, \'Y\');" ' +
+ 'onclick="DP_jQuery_' + dpuuid + '.datepicker._clickMonthYear(\'#' + inst.id + '\');"' +
+ '>';
+ for (; year <= endYear; year++) {
+ inst.yearshtml += '<option value="' + year + '"' +
+ (year == drawYear ? ' selected="selected"' : '') +
+ '>' + year + '</option>';
+ }
+ inst.yearshtml += '</select>';
+
  html += inst.yearshtml;
  inst.yearshtml = null;
- } else {
- // will be replaced later with inst.yearshtml
- html += '<select class="ui-datepicker-year"><option value="' + drawYear + '" selected="selected">' + drawYear + '</option></select>';
  }
  }
  html += this._get(inst, 'yearSuffix');
@@ -1713,6 +1709,28 @@ $.extend(Datepicker.prototype, {
  }
 });
 
+/*
+ * Bind hover events for datepicker elements.
+ * Done via delegate so the binding only occurs once in the lifetime of the parent div.
+ * Global instActive, set by _updateDatepicker allows the handlers to find their way back to the active picker.
+ */
+function bindHover(dpDiv) {
+ var selector = 'button, .ui-datepicker-prev, .ui-datepicker-next, .ui-datepicker-calendar td a';
+ return dpDiv.delegate(selector, 'mouseout', function() {
+ $(this).removeClass('ui-state-hover');
+ if (this.className.indexOf('ui-datepicker-prev') != -1) $(this).removeClass('ui-datepicker-prev-hover');
+ if (this.className.indexOf('ui-datepicker-next') != -1) $(this).removeClass('ui-datepicker-next-hover');
+ })
+ .delegate(selector, 'mouseover', function(){
+ if (!$.datepicker._isDisabledDatepicker( instActive.inline ? dpDiv.parent()[0] : instActive.input[0])) {
+ $(this).parents('.ui-datepicker-calendar').find('a').removeClass('ui-state-hover');
+ $(this).addClass('ui-state-hover');
+ if (this.className.indexOf('ui-datepicker-prev') != -1) $(this).addClass('ui-datepicker-prev-hover');
+ if (this.className.indexOf('ui-datepicker-next') != -1) $(this).addClass('ui-datepicker-next-hover');
+ }
+ });
+}
+
 /* jQuery extend now ignores nulls! */
 function extendRemove(target, props) {
  $.extend(target, props);
@@ -1764,7 +1782,7 @@ $.fn.datepicker = function(options){
 $.datepicker = new Datepicker(); // singleton instance
 $.datepicker.initialized = false;
 $.datepicker.uuid = new Date().getTime();
-$.datepicker.version = "1.8.11";
+$.datepicker.version = "1.8.13";
 
 // Workaround for #4055
 // Add another global to avoid noConflict issues with inline event handlers

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*!
- * jQuery UI Mouse 1.8.11
+ * jQuery UI Mouse 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -12,6 +12,11 @@
  */
 (function( $, undefined ) {
 
+var mouseHandled = false;
+$(document).mousedown(function(e) {
+ mouseHandled = false;
+});
+
 $.widget("ui.mouse", {
  options: {
  cancel: ':input,option',
@@ -44,9 +49,7 @@ $.widget("ui.mouse", {
 
  _mouseDown: function(event) {
  // don't let more than one widget handle mouseStart
- // TODO: figure out why we have to use originalEvent
- event.originalEvent = event.originalEvent || {};
- if (event.originalEvent.mouseHandled) { return; }
+ if(mouseHandled) {return};
 
  // we may have missed mouseup (out of window)
  (this._mouseStarted && this._mouseUp(event));
@@ -92,7 +95,8 @@ $.widget("ui.mouse", {
  .bind('mouseup.'+this.widgetName, this._mouseUpDelegate);
 
  event.preventDefault();
- event.originalEvent.mouseHandled = true;
+
+ mouseHandled = true;
  return true;
  },
 

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.position.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Position 1.8.11
+ * jQuery UI Position 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*!
- * jQuery UI Widget 1.8.11
+ * jQuery UI Widget 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.blind.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Blind 1.8.11
+ * jQuery UI Effects Blind 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.bounce.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Bounce 1.8.11
+ * jQuery UI Effects Bounce 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.clip.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Clip 1.8.11
+ * jQuery UI Effects Clip 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.core.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.core.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.core.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.core.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects 1.8.11
+ * jQuery UI Effects 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -7,24 +7,24 @@
  *
  * http://docs.jquery.com/UI/Effects/
  */
-jQuery.effects||function(f,j){function n(c){var a;if(c&&c.constructor==Array&&c.length==3)return c;if(a=/rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)/.exec(c))return[parseInt(a[1],10),parseInt(a[2],10),parseInt(a[3],10)];if(a=/rgb\(\s*([0-9]+(?:\.[0-9]+)?)\%\s*,\s*([0-9]+(?:\.[0-9]+)?)\%\s*,\s*([0-9]+(?:\.[0-9]+)?)\%\s*\)/.exec(c))return[parseFloat(a[1])*2.55,parseFloat(a[2])*2.55,parseFloat(a[3])*2.55];if(a=/#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/.exec(c))return[parseInt(a[1],
-16),parseInt(a[2],16),parseInt(a[3],16)];if(a=/#([a-fA-F0-9])([a-fA-F0-9])([a-fA-F0-9])/.exec(c))return[parseInt(a[1]+a[1],16),parseInt(a[2]+a[2],16),parseInt(a[3]+a[3],16)];if(/rgba\(0, 0, 0, 0\)/.exec(c))return o.transparent;return o[f.trim(c).toLowerCase()]}function s(c,a){var b;do{b=f.curCSS(c,a);if(b!=""&&b!="transparent"||f.nodeName(c,"body"))break;a="backgroundColor"}while(c=c.parentNode);return n(b)}function p(){var c=document.defaultView?document.defaultView.getComputedStyle(this,null):this.currentStyle,
-a={},b,d;if(c&&c.length&&c[0]&&c[c[0]])for(var e=c.length;e--;){b=c[e];if(typeof c[b]=="string"){d=b.replace(/\-(\w)/g,function(g,h){return h.toUpperCase()});a[d]=c[b]}}else for(b in c)if(typeof c[b]==="string")a[b]=c[b];return a}function q(c){var a,b;for(a in c){b=c[a];if(b==null||f.isFunction(b)||a in t||/scrollbar/.test(a)||!/color/i.test(a)&&isNaN(parseFloat(b)))delete c[a]}return c}function u(c,a){var b={_:0},d;for(d in a)if(c[d]!=a[d])b[d]=a[d];return b}function k(c,a,b,d){if(typeof c=="object"){d=
-a;b=null;a=c;c=a.effect}if(f.isFunction(a)){d=a;b=null;a={}}if(typeof a=="number"||f.fx.speeds[a]){d=b;b=a;a={}}if(f.isFunction(b)){d=b;b=null}a=a||{};b=b||a.duration;b=f.fx.off?0:typeof b=="number"?b:b in f.fx.speeds?f.fx.speeds[b]:f.fx.speeds._default;d=d||a.complete;return[c,a,b,d]}function m(c){if(!c||typeof c==="number"||f.fx.speeds[c])return true;if(typeof c==="string"&&!f.effects[c])return true;return false}f.effects={};f.each(["backgroundColor","borderBottomColor","borderLeftColor","borderRightColor",
-"borderTopColor","borderColor","color","outlineColor"],function(c,a){f.fx.step[a]=function(b){if(!b.colorInit){b.start=s(b.elem,a);b.end=n(b.end);b.colorInit=true}b.elem.style[a]="rgb("+Math.max(Math.min(parseInt(b.pos*(b.end[0]-b.start[0])+b.start[0],10),255),0)+","+Math.max(Math.min(parseInt(b.pos*(b.end[1]-b.start[1])+b.start[1],10),255),0)+","+Math.max(Math.min(parseInt(b.pos*(b.end[2]-b.start[2])+b.start[2],10),255),0)+")"}});var o={aqua:[0,255,255],azure:[240,255,255],beige:[245,245,220],black:[0,
+jQuery.effects||function(f,j){function m(c){var a;if(c&&c.constructor==Array&&c.length==3)return c;if(a=/rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)/.exec(c))return[parseInt(a[1],10),parseInt(a[2],10),parseInt(a[3],10)];if(a=/rgb\(\s*([0-9]+(?:\.[0-9]+)?)\%\s*,\s*([0-9]+(?:\.[0-9]+)?)\%\s*,\s*([0-9]+(?:\.[0-9]+)?)\%\s*\)/.exec(c))return[parseFloat(a[1])*2.55,parseFloat(a[2])*2.55,parseFloat(a[3])*2.55];if(a=/#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/.exec(c))return[parseInt(a[1],
+16),parseInt(a[2],16),parseInt(a[3],16)];if(a=/#([a-fA-F0-9])([a-fA-F0-9])([a-fA-F0-9])/.exec(c))return[parseInt(a[1]+a[1],16),parseInt(a[2]+a[2],16),parseInt(a[3]+a[3],16)];if(/rgba\(0, 0, 0, 0\)/.exec(c))return n.transparent;return n[f.trim(c).toLowerCase()]}function s(c,a){var b;do{b=f.curCSS(c,a);if(b!=""&&b!="transparent"||f.nodeName(c,"body"))break;a="backgroundColor"}while(c=c.parentNode);return m(b)}function o(){var c=document.defaultView?document.defaultView.getComputedStyle(this,null):this.currentStyle,
+a={},b,d;if(c&&c.length&&c[0]&&c[c[0]])for(var e=c.length;e--;){b=c[e];if(typeof c[b]=="string"){d=b.replace(/\-(\w)/g,function(g,h){return h.toUpperCase()});a[d]=c[b]}}else for(b in c)if(typeof c[b]==="string")a[b]=c[b];return a}function p(c){var a,b;for(a in c){b=c[a];if(b==null||f.isFunction(b)||a in t||/scrollbar/.test(a)||!/color/i.test(a)&&isNaN(parseFloat(b)))delete c[a]}return c}function u(c,a){var b={_:0},d;for(d in a)if(c[d]!=a[d])b[d]=a[d];return b}function k(c,a,b,d){if(typeof c=="object"){d=
+a;b=null;a=c;c=a.effect}if(f.isFunction(a)){d=a;b=null;a={}}if(typeof a=="number"||f.fx.speeds[a]){d=b;b=a;a={}}if(f.isFunction(b)){d=b;b=null}a=a||{};b=b||a.duration;b=f.fx.off?0:typeof b=="number"?b:b in f.fx.speeds?f.fx.speeds[b]:f.fx.speeds._default;d=d||a.complete;return[c,a,b,d]}function l(c){if(!c||typeof c==="number"||f.fx.speeds[c])return true;if(typeof c==="string"&&!f.effects[c])return true;return false}f.effects={};f.each(["backgroundColor","borderBottomColor","borderLeftColor","borderRightColor",
+"borderTopColor","borderColor","color","outlineColor"],function(c,a){f.fx.step[a]=function(b){if(!b.colorInit){b.start=s(b.elem,a);b.end=m(b.end);b.colorInit=true}b.elem.style[a]="rgb("+Math.max(Math.min(parseInt(b.pos*(b.end[0]-b.start[0])+b.start[0],10),255),0)+","+Math.max(Math.min(parseInt(b.pos*(b.end[1]-b.start[1])+b.start[1],10),255),0)+","+Math.max(Math.min(parseInt(b.pos*(b.end[2]-b.start[2])+b.start[2],10),255),0)+")"}});var n={aqua:[0,255,255],azure:[240,255,255],beige:[245,245,220],black:[0,
 0,0],blue:[0,0,255],brown:[165,42,42],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgrey:[169,169,169],darkgreen:[0,100,0],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkviolet:[148,0,211],fuchsia:[255,0,255],gold:[255,215,0],green:[0,128,0],indigo:[75,0,130],khaki:[240,230,140],lightblue:[173,216,230],lightcyan:[224,255,255],lightgreen:[144,238,144],lightgrey:[211,
-211,211],lightpink:[255,182,193],lightyellow:[255,255,224],lime:[0,255,0],magenta:[255,0,255],maroon:[128,0,0],navy:[0,0,128],olive:[128,128,0],orange:[255,165,0],pink:[255,192,203],purple:[128,0,128],violet:[128,0,128],red:[255,0,0],silver:[192,192,192],white:[255,255,255],yellow:[255,255,0],transparent:[255,255,255]},r=["add","remove","toggle"],t={border:1,borderBottom:1,borderColor:1,borderLeft:1,borderRight:1,borderTop:1,borderWidth:1,margin:1,padding:1};f.effects.animateClass=function(c,a,b,
-d){if(f.isFunction(b)){d=b;b=null}return this.queue("fx",function(){var e=f(this),g=e.attr("style")||" ",h=q(p.call(this)),l,v=e.attr("className");f.each(r,function(w,i){c[i]&&e[i+"Class"](c[i])});l=q(p.call(this));e.attr("className",v);e.animate(u(h,l),a,b,function(){f.each(r,function(w,i){c[i]&&e[i+"Class"](c[i])});if(typeof e.attr("style")=="object"){e.attr("style").cssText="";e.attr("style").cssText=g}else e.attr("style",g);d&&d.apply(this,arguments)});h=f.queue(this);l=h.splice(h.length-1,1)[0];
-h.splice(1,0,l);f.dequeue(this)})};f.fn.extend({_addClass:f.fn.addClass,addClass:function(c,a,b,d){return a?f.effects.animateClass.apply(this,[{add:c},a,b,d]):this._addClass(c)},_removeClass:f.fn.removeClass,removeClass:function(c,a,b,d){return a?f.effects.animateClass.apply(this,[{remove:c},a,b,d]):this._removeClass(c)},_toggleClass:f.fn.toggleClass,toggleClass:function(c,a,b,d,e){return typeof a=="boolean"||a===j?b?f.effects.animateClass.apply(this,[a?{add:c}:{remove:c},b,d,e]):this._toggleClass(c,
-a):f.effects.animateClass.apply(this,[{toggle:c},a,b,d])},switchClass:function(c,a,b,d,e){return f.effects.animateClass.apply(this,[{add:a,remove:c},b,d,e])}});f.extend(f.effects,{version:"1.8.11",save:function(c,a){for(var b=0;b<a.length;b++)a[b]!==null&&c.data("ec.storage."+a[b],c[0].style[a[b]])},restore:function(c,a){for(var b=0;b<a.length;b++)a[b]!==null&&c.css(a[b],c.data("ec.storage."+a[b]))},setMode:function(c,a){if(a=="toggle")a=c.is(":hidden")?"show":"hide";return a},getBaseline:function(c,
-a){var b;switch(c[0]){case "top":b=0;break;case "middle":b=0.5;break;case "bottom":b=1;break;default:b=c[0]/a.height}switch(c[1]){case "left":c=0;break;case "center":c=0.5;break;case "right":c=1;break;default:c=c[1]/a.width}return{x:c,y:b}},createWrapper:function(c){if(c.parent().is(".ui-effects-wrapper"))return c.parent();var a={width:c.outerWidth(true),height:c.outerHeight(true),"float":c.css("float")},b=f("<div></div>").addClass("ui-effects-wrapper").css({fontSize:"100%",background:"transparent",
-border:"none",margin:0,padding:0});c.wrap(b);b=c.parent();if(c.css("position")=="static"){b.css({position:"relative"});c.css({position:"relative"})}else{f.extend(a,{position:c.css("position"),zIndex:c.css("z-index")});f.each(["top","left","bottom","right"],function(d,e){a[e]=c.css(e);if(isNaN(parseInt(a[e],10)))a[e]="auto"});c.css({position:"relative",top:0,left:0,right:"auto",bottom:"auto"})}return b.css(a).show()},removeWrapper:function(c){if(c.parent().is(".ui-effects-wrapper"))return c.parent().replaceWith(c);
-return c},setTransition:function(c,a,b,d){d=d||{};f.each(a,function(e,g){unit=c.cssUnit(g);if(unit[0]>0)d[g]=unit[0]*b+unit[1]});return d}});f.fn.extend({effect:function(c){var a=k.apply(this,arguments),b={options:a[1],duration:a[2],callback:a[3]};a=b.options.mode;var d=f.effects[c];if(f.fx.off||!d)return a?this[a](b.duration,b.callback):this.each(function(){b.callback&&b.callback.call(this)});return d.call(this,b)},_show:f.fn.show,show:function(c){if(m(c))return this._show.apply(this,arguments);
-else{var a=k.apply(this,arguments);a[1].mode="show";return this.effect.apply(this,a)}},_hide:f.fn.hide,hide:function(c){if(m(c))return this._hide.apply(this,arguments);else{var a=k.apply(this,arguments);a[1].mode="hide";return this.effect.apply(this,a)}},__toggle:f.fn.toggle,toggle:function(c){if(m(c)||typeof c==="boolean"||f.isFunction(c))return this.__toggle.apply(this,arguments);else{var a=k.apply(this,arguments);a[1].mode="toggle";return this.effect.apply(this,a)}},cssUnit:function(c){var a=this.css(c),
-b=[];f.each(["em","px","%","pt"],function(d,e){if(a.indexOf(e)>0)b=[parseFloat(a),e]});return b}});f.easing.jswing=f.easing.swing;f.extend(f.easing,{def:"easeOutQuad",swing:function(c,a,b,d,e){return f.easing[f.easing.def](c,a,b,d,e)},easeInQuad:function(c,a,b,d,e){return d*(a/=e)*a+b},easeOutQuad:function(c,a,b,d,e){return-d*(a/=e)*(a-2)+b},easeInOutQuad:function(c,a,b,d,e){if((a/=e/2)<1)return d/2*a*a+b;return-d/2*(--a*(a-2)-1)+b},easeInCubic:function(c,a,b,d,e){return d*(a/=e)*a*a+b},easeOutCubic:function(c,
-a,b,d,e){return d*((a=a/e-1)*a*a+1)+b},easeInOutCubic:function(c,a,b,d,e){if((a/=e/2)<1)return d/2*a*a*a+b;return d/2*((a-=2)*a*a+2)+b},easeInQuart:function(c,a,b,d,e){return d*(a/=e)*a*a*a+b},easeOutQuart:function(c,a,b,d,e){return-d*((a=a/e-1)*a*a*a-1)+b},easeInOutQuart:function(c,a,b,d,e){if((a/=e/2)<1)return d/2*a*a*a*a+b;return-d/2*((a-=2)*a*a*a-2)+b},easeInQuint:function(c,a,b,d,e){return d*(a/=e)*a*a*a*a+b},easeOutQuint:function(c,a,b,d,e){return d*((a=a/e-1)*a*a*a*a+1)+b},easeInOutQuint:function(c,
-a,b,d,e){if((a/=e/2)<1)return d/2*a*a*a*a*a+b;return d/2*((a-=2)*a*a*a*a+2)+b},easeInSine:function(c,a,b,d,e){return-d*Math.cos(a/e*(Math.PI/2))+d+b},easeOutSine:function(c,a,b,d,e){return d*Math.sin(a/e*(Math.PI/2))+b},easeInOutSine:function(c,a,b,d,e){return-d/2*(Math.cos(Math.PI*a/e)-1)+b},easeInExpo:function(c,a,b,d,e){return a==0?b:d*Math.pow(2,10*(a/e-1))+b},easeOutExpo:function(c,a,b,d,e){return a==e?b+d:d*(-Math.pow(2,-10*a/e)+1)+b},easeInOutExpo:function(c,a,b,d,e){if(a==0)return b;if(a==
-e)return b+d;if((a/=e/2)<1)return d/2*Math.pow(2,10*(a-1))+b;return d/2*(-Math.pow(2,-10*--a)+2)+b},easeInCirc:function(c,a,b,d,e){return-d*(Math.sqrt(1-(a/=e)*a)-1)+b},easeOutCirc:function(c,a,b,d,e){return d*Math.sqrt(1-(a=a/e-1)*a)+b},easeInOutCirc:function(c,a,b,d,e){if((a/=e/2)<1)return-d/2*(Math.sqrt(1-a*a)-1)+b;return d/2*(Math.sqrt(1-(a-=2)*a)+1)+b},easeInElastic:function(c,a,b,d,e){c=1.70158;var g=0,h=d;if(a==0)return b;if((a/=e)==1)return b+d;g||(g=e*0.3);if(h<Math.abs(d)){h=d;c=g/4}else c=
-g/(2*Math.PI)*Math.asin(d/h);return-(h*Math.pow(2,10*(a-=1))*Math.sin((a*e-c)*2*Math.PI/g))+b},easeOutElastic:function(c,a,b,d,e){c=1.70158;var g=0,h=d;if(a==0)return b;if((a/=e)==1)return b+d;g||(g=e*0.3);if(h<Math.abs(d)){h=d;c=g/4}else c=g/(2*Math.PI)*Math.asin(d/h);return h*Math.pow(2,-10*a)*Math.sin((a*e-c)*2*Math.PI/g)+d+b},easeInOutElastic:function(c,a,b,d,e){c=1.70158;var g=0,h=d;if(a==0)return b;if((a/=e/2)==2)return b+d;g||(g=e*0.3*1.5);if(h<Math.abs(d)){h=d;c=g/4}else c=g/(2*Math.PI)*Math.asin(d/
-h);if(a<1)return-0.5*h*Math.pow(2,10*(a-=1))*Math.sin((a*e-c)*2*Math.PI/g)+b;return h*Math.pow(2,-10*(a-=1))*Math.sin((a*e-c)*2*Math.PI/g)*0.5+d+b},easeInBack:function(c,a,b,d,e,g){if(g==j)g=1.70158;return d*(a/=e)*a*((g+1)*a-g)+b},easeOutBack:function(c,a,b,d,e,g){if(g==j)g=1.70158;return d*((a=a/e-1)*a*((g+1)*a+g)+1)+b},easeInOutBack:function(c,a,b,d,e,g){if(g==j)g=1.70158;if((a/=e/2)<1)return d/2*a*a*(((g*=1.525)+1)*a-g)+b;return d/2*((a-=2)*a*(((g*=1.525)+1)*a+g)+2)+b},easeInBounce:function(c,
-a,b,d,e){return d-f.easing.easeOutBounce(c,e-a,0,d,e)+b},easeOutBounce:function(c,a,b,d,e){return(a/=e)<1/2.75?d*7.5625*a*a+b:a<2/2.75?d*(7.5625*(a-=1.5/2.75)*a+0.75)+b:a<2.5/2.75?d*(7.5625*(a-=2.25/2.75)*a+0.9375)+b:d*(7.5625*(a-=2.625/2.75)*a+0.984375)+b},easeInOutBounce:function(c,a,b,d,e){if(a<e/2)return f.easing.easeInBounce(c,a*2,0,d,e)*0.5+b;return f.easing.easeOutBounce(c,a*2-e,0,d,e)*0.5+d*0.5+b}})}(jQuery);
+211,211],lightpink:[255,182,193],lightyellow:[255,255,224],lime:[0,255,0],magenta:[255,0,255],maroon:[128,0,0],navy:[0,0,128],olive:[128,128,0],orange:[255,165,0],pink:[255,192,203],purple:[128,0,128],violet:[128,0,128],red:[255,0,0],silver:[192,192,192],white:[255,255,255],yellow:[255,255,0],transparent:[255,255,255]},q=["add","remove","toggle"],t={border:1,borderBottom:1,borderColor:1,borderLeft:1,borderRight:1,borderTop:1,borderWidth:1,margin:1,padding:1};f.effects.animateClass=function(c,a,b,
+d){if(f.isFunction(b)){d=b;b=null}return this.queue(function(){var e=f(this),g=e.attr("style")||" ",h=p(o.call(this)),r,v=e.attr("class");f.each(q,function(w,i){c[i]&&e[i+"Class"](c[i])});r=p(o.call(this));e.attr("class",v);e.animate(u(h,r),{queue:false,duration:a,easding:b,complete:function(){f.each(q,function(w,i){c[i]&&e[i+"Class"](c[i])});if(typeof e.attr("style")=="object"){e.attr("style").cssText="";e.attr("style").cssText=g}else e.attr("style",g);d&&d.apply(this,arguments);f.dequeue(this)}})})};
+f.fn.extend({_addClass:f.fn.addClass,addClass:function(c,a,b,d){return a?f.effects.animateClass.apply(this,[{add:c},a,b,d]):this._addClass(c)},_removeClass:f.fn.removeClass,removeClass:function(c,a,b,d){return a?f.effects.animateClass.apply(this,[{remove:c},a,b,d]):this._removeClass(c)},_toggleClass:f.fn.toggleClass,toggleClass:function(c,a,b,d,e){return typeof a=="boolean"||a===j?b?f.effects.animateClass.apply(this,[a?{add:c}:{remove:c},b,d,e]):this._toggleClass(c,a):f.effects.animateClass.apply(this,
+[{toggle:c},a,b,d])},switchClass:function(c,a,b,d,e){return f.effects.animateClass.apply(this,[{add:a,remove:c},b,d,e])}});f.extend(f.effects,{version:"1.8.13",save:function(c,a){for(var b=0;b<a.length;b++)a[b]!==null&&c.data("ec.storage."+a[b],c[0].style[a[b]])},restore:function(c,a){for(var b=0;b<a.length;b++)a[b]!==null&&c.css(a[b],c.data("ec.storage."+a[b]))},setMode:function(c,a){if(a=="toggle")a=c.is(":hidden")?"show":"hide";return a},getBaseline:function(c,a){var b;switch(c[0]){case "top":b=
+0;break;case "middle":b=0.5;break;case "bottom":b=1;break;default:b=c[0]/a.height}switch(c[1]){case "left":c=0;break;case "center":c=0.5;break;case "right":c=1;break;default:c=c[1]/a.width}return{x:c,y:b}},createWrapper:function(c){if(c.parent().is(".ui-effects-wrapper"))return c.parent();var a={width:c.outerWidth(true),height:c.outerHeight(true),"float":c.css("float")},b=f("<div></div>").addClass("ui-effects-wrapper").css({fontSize:"100%",background:"transparent",border:"none",margin:0,padding:0});
+c.wrap(b);b=c.parent();if(c.css("position")=="static"){b.css({position:"relative"});c.css({position:"relative"})}else{f.extend(a,{position:c.css("position"),zIndex:c.css("z-index")});f.each(["top","left","bottom","right"],function(d,e){a[e]=c.css(e);if(isNaN(parseInt(a[e],10)))a[e]="auto"});c.css({position:"relative",top:0,left:0,right:"auto",bottom:"auto"})}return b.css(a).show()},removeWrapper:function(c){if(c.parent().is(".ui-effects-wrapper"))return c.parent().replaceWith(c);return c},setTransition:function(c,
+a,b,d){d=d||{};f.each(a,function(e,g){unit=c.cssUnit(g);if(unit[0]>0)d[g]=unit[0]*b+unit[1]});return d}});f.fn.extend({effect:function(c){var a=k.apply(this,arguments),b={options:a[1],duration:a[2],callback:a[3]};a=b.options.mode;var d=f.effects[c];if(f.fx.off||!d)return a?this[a](b.duration,b.callback):this.each(function(){b.callback&&b.callback.call(this)});return d.call(this,b)},_show:f.fn.show,show:function(c){if(l(c))return this._show.apply(this,arguments);else{var a=k.apply(this,arguments);
+a[1].mode="show";return this.effect.apply(this,a)}},_hide:f.fn.hide,hide:function(c){if(l(c))return this._hide.apply(this,arguments);else{var a=k.apply(this,arguments);a[1].mode="hide";return this.effect.apply(this,a)}},__toggle:f.fn.toggle,toggle:function(c){if(l(c)||typeof c==="boolean"||f.isFunction(c))return this.__toggle.apply(this,arguments);else{var a=k.apply(this,arguments);a[1].mode="toggle";return this.effect.apply(this,a)}},cssUnit:function(c){var a=this.css(c),b=[];f.each(["em","px","%",
+"pt"],function(d,e){if(a.indexOf(e)>0)b=[parseFloat(a),e]});return b}});f.easing.jswing=f.easing.swing;f.extend(f.easing,{def:"easeOutQuad",swing:function(c,a,b,d,e){return f.easing[f.easing.def](c,a,b,d,e)},easeInQuad:function(c,a,b,d,e){return d*(a/=e)*a+b},easeOutQuad:function(c,a,b,d,e){return-d*(a/=e)*(a-2)+b},easeInOutQuad:function(c,a,b,d,e){if((a/=e/2)<1)return d/2*a*a+b;return-d/2*(--a*(a-2)-1)+b},easeInCubic:function(c,a,b,d,e){return d*(a/=e)*a*a+b},easeOutCubic:function(c,a,b,d,e){return d*
+((a=a/e-1)*a*a+1)+b},easeInOutCubic:function(c,a,b,d,e){if((a/=e/2)<1)return d/2*a*a*a+b;return d/2*((a-=2)*a*a+2)+b},easeInQuart:function(c,a,b,d,e){return d*(a/=e)*a*a*a+b},easeOutQuart:function(c,a,b,d,e){return-d*((a=a/e-1)*a*a*a-1)+b},easeInOutQuart:function(c,a,b,d,e){if((a/=e/2)<1)return d/2*a*a*a*a+b;return-d/2*((a-=2)*a*a*a-2)+b},easeInQuint:function(c,a,b,d,e){return d*(a/=e)*a*a*a*a+b},easeOutQuint:function(c,a,b,d,e){return d*((a=a/e-1)*a*a*a*a+1)+b},easeInOutQuint:function(c,a,b,d,e){if((a/=
+e/2)<1)return d/2*a*a*a*a*a+b;return d/2*((a-=2)*a*a*a*a+2)+b},easeInSine:function(c,a,b,d,e){return-d*Math.cos(a/e*(Math.PI/2))+d+b},easeOutSine:function(c,a,b,d,e){return d*Math.sin(a/e*(Math.PI/2))+b},easeInOutSine:function(c,a,b,d,e){return-d/2*(Math.cos(Math.PI*a/e)-1)+b},easeInExpo:function(c,a,b,d,e){return a==0?b:d*Math.pow(2,10*(a/e-1))+b},easeOutExpo:function(c,a,b,d,e){return a==e?b+d:d*(-Math.pow(2,-10*a/e)+1)+b},easeInOutExpo:function(c,a,b,d,e){if(a==0)return b;if(a==e)return b+d;if((a/=
+e/2)<1)return d/2*Math.pow(2,10*(a-1))+b;return d/2*(-Math.pow(2,-10*--a)+2)+b},easeInCirc:function(c,a,b,d,e){return-d*(Math.sqrt(1-(a/=e)*a)-1)+b},easeOutCirc:function(c,a,b,d,e){return d*Math.sqrt(1-(a=a/e-1)*a)+b},easeInOutCirc:function(c,a,b,d,e){if((a/=e/2)<1)return-d/2*(Math.sqrt(1-a*a)-1)+b;return d/2*(Math.sqrt(1-(a-=2)*a)+1)+b},easeInElastic:function(c,a,b,d,e){c=1.70158;var g=0,h=d;if(a==0)return b;if((a/=e)==1)return b+d;g||(g=e*0.3);if(h<Math.abs(d)){h=d;c=g/4}else c=g/(2*Math.PI)*Math.asin(d/
+h);return-(h*Math.pow(2,10*(a-=1))*Math.sin((a*e-c)*2*Math.PI/g))+b},easeOutElastic:function(c,a,b,d,e){c=1.70158;var g=0,h=d;if(a==0)return b;if((a/=e)==1)return b+d;g||(g=e*0.3);if(h<Math.abs(d)){h=d;c=g/4}else c=g/(2*Math.PI)*Math.asin(d/h);return h*Math.pow(2,-10*a)*Math.sin((a*e-c)*2*Math.PI/g)+d+b},easeInOutElastic:function(c,a,b,d,e){c=1.70158;var g=0,h=d;if(a==0)return b;if((a/=e/2)==2)return b+d;g||(g=e*0.3*1.5);if(h<Math.abs(d)){h=d;c=g/4}else c=g/(2*Math.PI)*Math.asin(d/h);if(a<1)return-0.5*
+h*Math.pow(2,10*(a-=1))*Math.sin((a*e-c)*2*Math.PI/g)+b;return h*Math.pow(2,-10*(a-=1))*Math.sin((a*e-c)*2*Math.PI/g)*0.5+d+b},easeInBack:function(c,a,b,d,e,g){if(g==j)g=1.70158;return d*(a/=e)*a*((g+1)*a-g)+b},easeOutBack:function(c,a,b,d,e,g){if(g==j)g=1.70158;return d*((a=a/e-1)*a*((g+1)*a+g)+1)+b},easeInOutBack:function(c,a,b,d,e,g){if(g==j)g=1.70158;if((a/=e/2)<1)return d/2*a*a*(((g*=1.525)+1)*a-g)+b;return d/2*((a-=2)*a*(((g*=1.525)+1)*a+g)+2)+b},easeInBounce:function(c,a,b,d,e){return d-f.easing.easeOutBounce(c,
+e-a,0,d,e)+b},easeOutBounce:function(c,a,b,d,e){return(a/=e)<1/2.75?d*7.5625*a*a+b:a<2/2.75?d*(7.5625*(a-=1.5/2.75)*a+0.75)+b:a<2.5/2.75?d*(7.5625*(a-=2.25/2.75)*a+0.9375)+b:d*(7.5625*(a-=2.625/2.75)*a+0.984375)+b},easeInOutBounce:function(c,a,b,d,e){if(a<e/2)return f.easing.easeInBounce(c,a*2,0,d,e)*0.5+b;return f.easing.easeOutBounce(c,a*2-e,0,d,e)*0.5+d*0.5+b}})}(jQuery);

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.drop.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.drop.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.drop.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.drop.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Drop 1.8.11
+ * jQuery UI Effects Drop 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.explode.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.explode.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.explode.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.explode.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Explode 1.8.11
+ * jQuery UI Effects Explode 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fade.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fade.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fade.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fade.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Fade 1.8.11
+ * jQuery UI Effects Fade 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fold.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fold.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fold.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.fold.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Fold 1.8.11
+ * jQuery UI Effects Fold 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.highlight.min.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.highlight.min.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.highlight.min.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/minified/jquery.effects.highlight.min.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects Highlight 1.8.11
+ * jQuery UI Effects Highlight 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.core.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Effects 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -231,12 +231,12 @@ $.effects.animateClass = function(value,
  easing = null;
  }
 
- return this.queue('fx', function() {
+ return this.queue(function() {
  var that = $(this),
  originalStyleAttr = that.attr('style') || ' ',
  originalStyle = filterStyles(getElementStyles.call(this)),
  newStyle,
- className = that.attr('className');
+ className = that.attr('class');
 
  $.each(classAnimationActions, function(i, action) {
  if (value[action]) {
@@ -244,28 +244,27 @@ $.effects.animateClass = function(value,
  }
  });
  newStyle = filterStyles(getElementStyles.call(this));
- that.attr('className', className);
+ that.attr('class', className);
 
- that.animate(styleDifference(originalStyle, newStyle), duration, easing, function() {
- $.each(classAnimationActions, function(i, action) {
- if (value[action]) { that[action + 'Class'](value[action]); }
- });
- // work around bug in IE by clearing the cssText before setting it
- if (typeof that.attr('style') == 'object') {
- that.attr('style').cssText = '';
- that.attr('style').cssText = originalStyleAttr;
- } else {
- that.attr('style', originalStyleAttr);
+ that.animate(styleDifference(originalStyle, newStyle), {
+ queue: false,
+ duration: duration,
+ easding: easing,
+ complete: function() {
+ $.each(classAnimationActions, function(i, action) {
+ if (value[action]) { that[action + 'Class'](value[action]); }
+ });
+ // work around bug in IE by clearing the cssText before setting it
+ if (typeof that.attr('style') == 'object') {
+ that.attr('style').cssText = '';
+ that.attr('style').cssText = originalStyleAttr;
+ } else {
+ that.attr('style', originalStyleAttr);
+ }
+ if (callback) { callback.apply(this, arguments); }
+ $.dequeue( this );
  }
- if (callback) { callback.apply(this, arguments); }
  });
-
- // $.animate adds a function to the end of the queue
- // but we want it at the front
- var queue = $.queue(this),
- anim = queue.splice(queue.length - 1, 1)[0];
- queue.splice(1, 0, anim);
- $.dequeue(this);
  });
 };
 
@@ -307,7 +306,7 @@ $.fn.extend({
 /******************************************************************************/
 
 $.extend($.effects, {
- version: "1.8.11",
+ version: "1.8.13",
 
  // Saves a set of properties in a data storage
  save: function(element, set) {
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Effects 1.8.11
+ * jQuery UI Effects 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.effects.drop.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.accordion.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Accordion 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -518,7 +518,7 @@ $.widget( "ui.accordion", {
 });
 
 $.extend( $.ui.accordion, {
- version: "1.8.11",
+ version: "1.8.13",
  animations: {
  slide: function( options, additions ) {
  options = $.extend({
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Accordion 1.8.11
+ * jQuery UI Accordion 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.autocomplete.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.dialog.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Dialog 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -37,6 +37,18 @@ var uiDialogClasses =
  maxWidth: true,
  minHeight: true,
  minWidth: true
+ },
+ // support for jQuery 1.3.2 - handle common attrFn methods for dialog
+ attrFn = $.attrFn || {
+ val: true,
+ css: true,
+ html: true,
+ text: true,
+ data: true,
+ width: true,
+ height: true,
+ offset: true,
+ click: true
  };
 
 $.widget("ui.dialog", {
@@ -376,12 +388,21 @@ $.widget("ui.dialog", {
  { click: props, text: name } :
  props;
  var button = $('<button type="button"></button>')
- .attr( props, true )
- .unbind('click')
  .click(function() {
  props.click.apply(self.element[0], arguments);
  })
  .appendTo(uiButtonSet);
+ // can't use .attr( props, true ) with jQuery 1.3.2.
+ $.each( props, function( key, value ) {
+ if ( key === "click" ) {
+ return;
+ }
+ if ( key in attrFn ) {
+ button[ key ]( value );
+ } else {
+ button.attr( key, value );
+ }
+ });
  if ($.fn.button) {
  button.button();
  }
@@ -681,7 +702,7 @@ $.widget("ui.dialog", {
 });
 
 $.extend($.ui.dialog, {
- version: "1.8.11",
+ version: "1.8.13",
 
  uuid: 0,
  maxZ: 0,
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Dialog 1.8.11
+ * jQuery UI Dialog 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.draggable.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Draggable 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -79,6 +79,16 @@ $.widget("ui.draggable", $.ui.mouse, {
  this.handle = this._getHandle(event);
  if (!this.handle)
  return false;
+
+ $(o.iframeFix === true ? "iframe" : o.iframeFix).each(function() {
+ $('<div class="ui-draggable-iframeFix" style="background: #fff;"></div>')
+ .css({
+ width: this.offsetWidth+"px", height: this.offsetHeight+"px",
+ position: "absolute", opacity: "0.001", zIndex: 1000
+ })
+ .css($(this).offset())
+ .appendTo("body");
+ });
 
  return true;
 
@@ -212,6 +222,16 @@ $.widget("ui.draggable", $.ui.mouse, {
  return false;
  },
 
+ _mouseUp: function(event) {
+ if (this.options.iframeFix === true) {
+ $("div.ui-draggable-iframeFix").each(function() {
+ this.parentNode.removeChild(this);
+ }); //Remove frame helpers
+ }
+
+ return $.ui.mouse.prototype._mouseUp.call(this, event);
+ },
+
  cancel: function() {
 
  if(this.helper.is(".ui-draggable-dragging")) {
@@ -241,7 +261,7 @@ $.widget("ui.draggable", $.ui.mouse, {
  _createHelper: function(event) {
 
  var o = this.options;
- var helper = $.isFunction(o.helper) ? $(o.helper.apply(this.element[0], [event])) : (o.helper == 'clone' ? this.element.clone() : this.element);
+ var helper = $.isFunction(o.helper) ? $(o.helper.apply(this.element[0], [event])) : (o.helper == 'clone' ? this.element.clone().removeAttr('id') : this.element);
 
  if(!helper.parents('body').length)
  helper.appendTo((o.appendTo == 'parent' ? this.element[0].parentNode : o.appendTo));
@@ -342,16 +362,19 @@ $.widget("ui.draggable", $.ui.mouse, {
  ];
 
  if(!(/^(document|window|parent)$/).test(o.containment) && o.containment.constructor != Array) {
- var ce = $(o.containment)[0]; if(!ce) return;
- var co = $(o.containment).offset();
+        var c = $(o.containment);
+ var ce = c[0]; if(!ce) return;
+ var co = c.offset();
  var over = ($(ce).css("overflow") != 'hidden');
 
  this.containment = [
- co.left + (parseInt($(ce).css("borderLeftWidth"),10) || 0) + (parseInt($(ce).css("paddingLeft"),10) || 0),
- co.top + (parseInt($(ce).css("borderTopWidth"),10) || 0) + (parseInt($(ce).css("paddingTop"),10) || 0),
- co.left+(over ? Math.max(ce.scrollWidth,ce.offsetWidth) : ce.offsetWidth) - (parseInt($(ce).css("borderLeftWidth"),10) || 0) - (parseInt($(ce).css("paddingRight"),10) || 0) - this.helperProportions.width - this.margins.left - this.margins.right,
- co.top+(over ? Math.max(ce.scrollHeight,ce.offsetHeight) : ce.offsetHeight) - (parseInt($(ce).css("borderTopWidth"),10) || 0) - (parseInt($(ce).css("paddingBottom"),10) || 0) - this.helperProportions.height - this.margins.top  - this.margins.bottom
+ (parseInt($(ce).css("borderLeftWidth"),10) || 0) + (parseInt($(ce).css("paddingLeft"),10) || 0),
+ (parseInt($(ce).css("borderTopWidth"),10) || 0) + (parseInt($(ce).css("paddingTop"),10) || 0),
+ (over ? Math.max(ce.scrollWidth,ce.offsetWidth) : ce.offsetWidth) - (parseInt($(ce).css("borderLeftWidth"),10) || 0) - (parseInt($(ce).css("paddingRight"),10) || 0) - this.helperProportions.width - this.margins.left - this.margins.right,
+ (over ? Math.max(ce.scrollHeight,ce.offsetHeight) : ce.offsetHeight) - (parseInt($(ce).css("borderTopWidth"),10) || 0) - (parseInt($(ce).css("paddingBottom"),10) || 0) - this.helperProportions.height - this.margins.top  - this.margins.bottom
  ];
+ this.relative_container = c;
+
  } else if(o.containment.constructor == Array) {
  this.containment = o.containment;
  }
@@ -393,20 +416,31 @@ $.widget("ui.draggable", $.ui.mouse, {
  */
 
  if(this.originalPosition) { //If we are not dragging yet, we won't check for options
-
- if(this.containment) {
- if(event.pageX - this.offset.click.left < this.containment[0]) pageX = this.containment[0] + this.offset.click.left;
- if(event.pageY - this.offset.click.top < this.containment[1]) pageY = this.containment[1] + this.offset.click.top;
- if(event.pageX - this.offset.click.left > this.containment[2]) pageX = this.containment[2] + this.offset.click.left;
- if(event.pageY - this.offset.click.top > this.containment[3]) pageY = this.containment[3] + this.offset.click.top;
+         var containment;
+         if(this.containment) {
+ if (this.relative_container){
+     var co = this.relative_container.offset();
+     containment = [ this.containment[0] + co.left,
+     this.containment[1] + co.top,
+     this.containment[2] + co.left,
+     this.containment[3] + co.top ];
+ }
+ else {
+     containment = this.containment;
+ }
+
+ if(event.pageX - this.offset.click.left < containment[0]) pageX = containment[0] + this.offset.click.left;
+ if(event.pageY - this.offset.click.top < containment[1]) pageY = containment[1] + this.offset.click.top;
+ if(event.pageX - this.offset.click.left > containment[2]) pageX = containment[2] + this.offset.click.left;
+ if(event.pageY - this.offset.click.top > containment[3]) pageY = containment[3] + this.offset.click.top;
  }
 
  if(o.grid) {
  var top = this.originalPageY + Math.round((pageY - this.originalPageY) / o.grid[1]) * o.grid[1];
- pageY = this.containment ? (!(top - this.offset.click.top < this.containment[1] || top - this.offset.click.top > this.containment[3]) ? top : (!(top - this.offset.click.top < this.containment[1]) ? top - o.grid[1] : top + o.grid[1])) : top;
+ pageY = containment ? (!(top - this.offset.click.top < containment[1] || top - this.offset.click.top > containment[3]) ? top : (!(top - this.offset.click.top < containment[1]) ? top - o.grid[1] : top + o.grid[1])) : top;
 
  var left = this.originalPageX + Math.round((pageX - this.originalPageX) / o.grid[0]) * o.grid[0];
- pageX = this.containment ? (!(left - this.offset.click.left < this.containment[0] || left - this.offset.click.left > this.containment[2]) ? left : (!(left - this.offset.click.left < this.containment[0]) ? left - o.grid[0] : left + o.grid[0])) : left;
+ pageX = containment ? (!(left - this.offset.click.left < containment[0] || left - this.offset.click.left > containment[2]) ? left : (!(left - this.offset.click.left < containment[0]) ? left - o.grid[0] : left + o.grid[0])) : left;
  }
 
  }
@@ -461,7 +495,7 @@ $.widget("ui.draggable", $.ui.mouse, {
 });
 
 $.extend($.ui.draggable, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 $.ui.plugin.add("draggable", "connectToSortable", {
@@ -546,7 +580,7 @@ $.ui.plugin.add("draggable", "connectToS
  //Now we fake the start of dragging for the sortable instance,
  //by cloning the list group item, appending it to the sortable and using it as inst.currentItem
  //We can then fire the start event of the sortable with our passed browser event, and our own helper (so it doesn't create a new one)
- this.instance.currentItem = $(self).clone().appendTo(this.instance.element).data("sortable-item", true);
+ this.instance.currentItem = $(self).clone().removeAttr('id').appendTo(this.instance.element).data("sortable-item", true);
  this.instance.options._helper = this.instance.options.helper; //Store helper option to later restore it
  this.instance.options.helper = function() { return ui.helper[0]; };
 
@@ -616,24 +650,6 @@ $.ui.plugin.add("draggable", "cursor", {
  }
 });
 
-$.ui.plugin.add("draggable", "iframeFix", {
- start: function(event, ui) {
- var o = $(this).data('draggable').options;
- $(o.iframeFix === true ? "iframe" : o.iframeFix).each(function() {
- $('<div class="ui-draggable-iframeFix" style="background: #fff;"></div>')
- .css({
- width: this.offsetWidth+"px", height: this.offsetHeight+"px",
- position: "absolute", opacity: "0.001", zIndex: 1000
- })
- .css($(this).offset())
- .appendTo("body");
- });
- },
- stop: function(event, ui) {
- $("div.ui-draggable-iframeFix").each(function() { this.parentNode.removeChild(this); }); //Remove frame helpers
- }
-});
-
 $.ui.plugin.add("draggable", "opacity", {
  start: function(event, ui) {
  var t = $(ui.helper), o = $(this).data('draggable').options;
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Draggable 1.8.11
+ * jQuery UI Draggable 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.droppable.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Droppable 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -147,7 +147,7 @@ $.widget("ui.droppable", {
 });
 
 $.extend($.ui.droppable, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 $.ui.intersect = function(draggable, droppable, toleranceMode) {
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Droppable 1.8.11
+ * jQuery UI Droppable 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.mouse.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.progressbar.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Progressbar 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -95,6 +95,7 @@ $.widget( "ui.progressbar", {
  }
 
  this.valueDiv
+ .toggle( value > this.min )
  .toggleClass( "ui-corner-right", value === this.options.max )
  .width( percentage.toFixed(0) + "%" );
  this.element.attr( "aria-valuenow", value );
@@ -102,7 +103,7 @@ $.widget( "ui.progressbar", {
 });
 
 $.extend( $.ui.progressbar, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 })( jQuery );
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Progressbar 1.8.11
+ * jQuery UI Progressbar 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.resizable.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Resizable 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -176,10 +176,12 @@ $.widget("ui.resizable", $.ui.mouse, {
  $(this.element)
  .addClass("ui-resizable-autohide")
  .hover(function() {
+ if (o.disabled) return;
  $(this).removeClass("ui-resizable-autohide");
  self._handles.show();
  },
  function(){
+ if (o.disabled) return;
  if (!self.resizing) {
  $(this).addClass("ui-resizable-autohide");
  self._handles.hide();
@@ -519,7 +521,7 @@ $.widget("ui.resizable", $.ui.mouse, {
 });
 
 $.extend($.ui.resizable, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 /*
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Resizable 1.8.11
+ * jQuery UI Resizable 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.selectable.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Selectable 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -260,7 +260,7 @@ $.widget("ui.selectable", $.ui.mouse, {
 });
 
 $.extend($.ui.selectable, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 })(jQuery);
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Selectable 1.8.11
+ * jQuery UI Selectable 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.slider.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Slider 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -36,7 +36,11 @@ $.widget( "ui.slider", $.ui.mouse, {
 
  _create: function() {
  var self = this,
- o = this.options;
+ o = this.options,
+ existingHandles = this.element.find( ".ui-slider-handle" ).addClass( "ui-state-default ui-corner-all" ),
+ handle = "<a class='ui-slider-handle ui-state-default ui-corner-all' href='#'></a>",
+ handleCount = ( o.values && o.values.length ) || 1,
+ handles = [];
 
  this._keySliding = false;
  this._mouseSliding = false;
@@ -50,57 +54,35 @@ $.widget( "ui.slider", $.ui.mouse, {
  " ui-slider-" + this.orientation +
  " ui-widget" +
  " ui-widget-content" +
- " ui-corner-all" );
-
- if ( o.disabled ) {
- this.element.addClass( "ui-slider-disabled ui-disabled" );
- }
+ " ui-corner-all" +
+ ( o.disabled ? " ui-slider-disabled ui-disabled" : "" ) );
 
  this.range = $([]);
 
  if ( o.range ) {
  if ( o.range === true ) {
- this.range = $( "<div></div>" );
  if ( !o.values ) {
  o.values = [ this._valueMin(), this._valueMin() ];
  }
  if ( o.values.length && o.values.length !== 2 ) {
  o.values = [ o.values[0], o.values[0] ];
  }
- } else {
- this.range = $( "<div></div>" );
- }
-
- this.range
- .appendTo( this.element )
- .addClass( "ui-slider-range" );
-
- if ( o.range === "min" || o.range === "max" ) {
- this.range.addClass( "ui-slider-range-" + o.range );
  }
 
- // note: this isn't the most fittingly semantic framework class for this element,
- // but worked best visually with a variety of themes
- this.range.addClass( "ui-widget-header" );
- }
-
- if ( $( ".ui-slider-handle", this.element ).length === 0 ) {
- $( "<a href='#'></a>" )
+ this.range = $( "<div></div>" )
  .appendTo( this.element )
- .addClass( "ui-slider-handle" );
+ .addClass( "ui-slider-range" +
+ // note: this isn't the most fittingly semantic framework class for this element,
+ // but worked best visually with a variety of themes
+ " ui-widget-header" +
+ ( ( o.range === "min" || o.range === "max" ) ? " ui-slider-range-" + o.range : "" ) );
  }
 
- if ( o.values && o.values.length ) {
- while ( $(".ui-slider-handle", this.element).length < o.values.length ) {
- $( "<a href='#'></a>" )
- .appendTo( this.element )
- .addClass( "ui-slider-handle" );
- }
+ for ( var i = existingHandles.length; i < handleCount; i += 1 ) {
+ handles.push( handle );
  }
 
- this.handles = $( ".ui-slider-handle", this.element )
- .addClass( "ui-state-default" +
- " ui-corner-all" );
+ this.handles = existingHandles.add( $( handles.join( "" ) ).appendTo( self.element ) );
 
  this.handle = this.handles.eq( 0 );
 
@@ -466,6 +448,7 @@ $.widget( "ui.slider", $.ui.mouse, {
  this.options.value = this._trimAlignValue( newValue );
  this._refreshValue();
  this._change( null, 0 );
+ return;
  }
 
  return this._value();
@@ -480,6 +463,7 @@ $.widget( "ui.slider", $.ui.mouse, {
  this.options.values[ index ] = this._trimAlignValue( newValue );
  this._refreshValue();
  this._change( null, index );
+ return;
  }
 
  if ( arguments.length ) {
@@ -676,7 +660,7 @@ $.widget( "ui.slider", $.ui.mouse, {
 });
 
 $.extend( $.ui.slider, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 }(jQuery));
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Slider 1.8.11
+ * jQuery UI Slider 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.sortable.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Sortable 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -50,7 +50,7 @@ $.widget("ui.sortable", $.ui.mouse, {
  this.refresh();
 
  //Let's determine if the items are being displayed horizontally
- this.floating = this.items.length ? (/left|right/).test(this.items[0].item.css('float')) || (/inline|table-cell/).test(this.items[0].item.css('display')) : false;
+ this.floating = this.items.length ? o.axis === 'x' || (/left|right/).test(this.items[0].item.css('float')) || (/inline|table-cell/).test(this.items[0].item.css('display')) : false;
 
  //Let's determine the parent's offset
  this.offset = this.element.offset();
@@ -615,6 +615,10 @@ $.widget("ui.sortable", $.ui.mouse, {
  for (var i = this.items.length - 1; i >= 0; i--){
  var item = this.items[i];
 
+ //We ignore calculating positions of all connected containers when we're not over them
+ if(item.instance != this.currentContainer && this.currentContainer && item.item[0] != this.currentItem[0])
+ continue;
+
  var t = this.options.toleranceElement ? $(this.options.toleranceElement, item.item) : item.item;
 
  if (!fast) {
@@ -1067,7 +1071,7 @@ $.widget("ui.sortable", $.ui.mouse, {
 });
 
 $.extend($.ui.sortable, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 })(jQuery);
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Sortable 1.8.11
+ * jQuery UI Sortable 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================
--- ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js (original)
+++ ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.tabs.js Thu May 19 11:59:43 2011
@@ -1,5 +1,5 @@
 /*
* jQuery UI Tabs 1.8.11
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
  * Dual licensed under the MIT or GPL Version 2 licenses.
@@ -698,7 +698,7 @@ $.widget( "ui.tabs", {
 });
 
 $.extend( $.ui.tabs, {
- version: "1.8.11"
+ version: "1.8.13"
 });
 
 /*
@@ -1,5 +1,5 @@
 /*
- * jQuery UI Tabs 1.8.11
+ * jQuery UI Tabs 1.8.13
  *
  * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)

Modified: ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js
URL: http://svn.apache.org/viewvc/ofbiz/trunk/framework/images/webapp/images/jquery/ui/development-bundle/ui/jquery.ui.widget.js?rev=1124697&r1=1124696&r2=1124697&view=diff
==============================================================================